@@ -64,9 +64,6 @@ func unique(in []config.File) []config.File {
 }
 
 func destinationFor(f config.File, path string) string {
-	if f.Destination == "" {
-		return path
-	}
 	if f.StripParent {
 		return filepath.Join(f.Destination, filepath.Base(path))
 	}
